# Renamed to Deep Search

This agent has been renamed to **[Deep Search](../deep-search)** to better reflect its core functionality.

**New location:** [`python/agents/deep-search`](../deep-search)
**New template:** `adk@deep-search` (instead of `adk@gemini-fullstack`)
